Ocyan plugin Oscar Compare
==========================

Installation
------------
Add `ocyan.plugin.oscar_compare` to your projects dependencies.

Usage
-----
The Oscar Compare plugin allows customers to compare products by adding them to the comparator and select "start comparing". The customers can also remove products from the comparator.